@@ -12,11 +12,12 @@ pkglist_to_deps() {
         -e 's,^\(util-linux\|fdisk\)$,fdisk | util-linux (<< 2.29.2),' \
         -e 's,^\(dhcpcd-base\|isc-dhcp-client\)$,dhcpcd-base | isc-dhcp-client,' \
         -e '/^\(bash\|coreutils\|findutils\|grep\|gzip\|libc-bin\|sed\|tar\)$/d' \
+        -e '/^reiserfsprogs$/d' \
         | tr '\n' ','
     echo
 }
 
-for p in gfs2 hfsplus jfs nilfs reiserfs rescue rsync xfs zfs
+for p in gfs2 hfsplus jfs nilfs rescue rsync xfs
 do
     cat debian/libguestfs-$p/usr/lib/*-*/guestfs/supermin.d/packages-$p \
         |  pkglist_to_deps \
